@@ -4,7 +4,7 @@ use 5.008_003;
 
 package SWISH::3;
 
-our $VERSION = '1.000012';
+our $VERSION = '1.000013';
 my $version = $VERSION;
 $VERSION = eval $VERSION;    # numerify
 
@@ -432,7 +432,9 @@ I<str> should contain the API headers.
 
 =head2 parse_fh( I<filehandle> )
 
-B<Not yet implemented.>
+Calls the C function of the same name on I<filehandle>. B<Note> that
+the stream pointed to by I<filehandle> should contain the API headers.
+See L<SWISH::3::Headers>.
 
 =head2 error
 
